#
# spec file for package nghttp2
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lib_name lib%{name}-14
%define lib_name_asio lib%{name}_asio1
Name:           nghttp2
Version:        1.3.4
Release:        3.22
Summary:        Implementation of Hypertext Transfer Protocol version 2 in C
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://nghttp2.org/
#Git-Clone:	git://github.com/tatsuhiro-t/nghttp2
Source:         https://github.com/tatsuhiro-t/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch1:         nghttp2-remove-python-build.patch
# CVE-2016-1544 upstream commit 026919b7ea89b6167f0fb84824a644fbbdabc8e7
Patch2:         nghttp2-limit-incoming.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-Cython
BuildRequires:  python-Sphinx
BuildRequires:  python-setuptools
BuildRequires:  pkgconfig(cunit)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is an implementation of Hypertext Transfer Protocol version 2 in C.

The framing layer of HTTP/2 is implemented as a form of reusable C library.
On top of that, we have implemented HTTP/2 client, server and proxy.
We have also developed load test and benchmarking tool for HTTP/2 and SPDY.

HPACK encoder and decoder are available as public API.

%package -n %{lib_name}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{lib_name}
Shared C libraries for implementation of Hypertext Transfer Protocol version 2

%package -n %{lib_name_asio}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{lib_name_asio}
Shared librarios for asynchronous implementation of Hypertext Transfer Protocol version 2

%package -n python-%{name}
Summary:        Python bindings for %{name}
Group:          Development/Libraries/Python

%description -n python-%{name}
Python bindings for implementation of Hypertext Transfer Protocol version 2

%package -n lib%{name}-devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Provides:       %{name}-devel

%description -n lib%{name}-devel
Development files for usage with lib%{name}, which implements Hypertext
Transfer Protocol version 2.

%package -n lib%{name}_asio-devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{lib_name_asio} = %{version}

%description -n lib%{name}_asio-devel
Development files for usage with lib%{name}_aio, which implements asynchronous
Hypertext Transfer Protocol version 2.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML

%description doc
Documentation for %{name}, which includes a shared C library, HTTP/2 client,
server and proxy.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
autoreconf -fiv
%configure \
  --disable-silent-rules \
	--enable-asio-lib \
  --enable-python-bindings \
	--disable-static
make %{?_smp_mflags} all html
pushd python
make %{?_smp_mflags} nghttp2.c
python setup.py build
popd

%check
make %{?_smp_mflags} check

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
pushd python
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
# do not ship these
find %{buildroot} -type f -name "*.la" -delete -print
# none of applications using these man pages is built
rm -rf %{buildroot}%{_mandir}/man1/*
rm -rf doc/manual/html/.buildinfo

%post -n %{lib_name} -p /sbin/ldconfig

%post -n %{lib_name_asio} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name_asio} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/deflatehd
%{_bindir}/inflatehd
%{_datadir}/%{name}

%files -n %{lib_name}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/lib%{name}.so.*

%files -n %{lib_name_asio}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/lib%{name}_asio.so.*

%files -n python-%{name}
%defattr(-,root,root)
%{python_sitearch}/nghttp2.so
%{python_sitearch}/python_nghttp2-%{version}-py%{py_ver}.egg-info

%files -n lib%{name}-devel
%defattr(-,root,root)
%doc ChangeLog
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/nghttp2.h
%{_includedir}/%{name}/nghttp2ver.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc

%files -n lib%{name}_asio-devel
%defattr(-,root,root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/asio_http2.h
%{_includedir}/nghttp2/asio_http2_client.h
%{_includedir}/nghttp2/asio_http2_server.h
%{_libdir}/lib%{name}_asio.so
%{_libdir}/pkgconfig/lib%{name}_asio.pc

%files doc
%defattr(-,root,root)
%doc AUTHORS ChangeLog
%doc doc/manual/html
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/README.rst

%changelog
* Fri Feb 26 2016 mpluskal@suse.com
- Fix CVE-2016-1544 (boo#966514)
* Sun Sep 27 2015 mpluskal@suse.com
- Update to 1.3.4
  * Make traditional init script fail if new config file is broken
    (Patch from Janusz Dziemidowicz)
  * nghttpx-logrotate: Don't use killall since we have multiple
    processes
  * nghttpx: Fix improper signal handling
- Changes for 1.3.3
  * Fix bug in padding handling of DATA frame
  * Use hash table for dynamic table lookup
  * More warning flags for --enable-werror
  * Update mruby
  * h2load: HTTP/1.1 support (Patch from Lucas Pardue)
  * nghttpx: Do not try to set TCP_NODELAY when frontend is an
    UNIX socket (Patch from Janusz Dziemidowicz)
  * nghttpx: Chown UNIX domain socket to user specified as --user
  * nghttpx: Split monolithic one process into control and worker
    processes
  * nghttpx: Handle SSL/TLS data following PROXY protocol line
- Changes for 1.3.2
  * Check header block limit after new stream is opened
  * nghttp: Show error if HEADERS frame cannot be sent for
    whatever reason
  * nghttpx: Fix assertion failure on TLS handshake
  * nghttpx: Add x-http2-push header field for pushed resource
  * nghttpx: Fix compile error with --disable-threads
* Mon Sep 14 2015 mpluskal@suse.com
- Update to 1.3.1
  * Avoid usage of typeof and replace __builtin_offsetof with
    offsetof
  * Honor stream->weight even if stream->last_writelen is 0
  * Compile third-party libraries if hpack-tools is enabled
  * nghttpx-init: Start nghttpx with --daemon
  * Bundle sphinxcontrib.rubydomain https://bitbucket.org/birkenfeld/sphinx-contrib/src/default/rubydomain/
  * Bundle mruby
  * h2load: Record TTFB on first byte of response body, rather
    than first socket read
  * h2load: Improve checking for timing script input, prevent
    false positive in certain situations
  * nghttpx: Implement PROXY protocol version 1
    (--accept-proxy-protocol option)
  * nghttpx: Allow link header server push for HTTP/2 backend
    as well
  * nghttpx: Don't initiate push if client disabled push
  * nghttpx: Allow absolute URI in Link header field for push
  * nghttpx: Fix crash with multi workers and QUIT signal
  * nghttpx: Add mruby support which is disabled by default
    (use --with-mruby configure option to enable it)
  * nghttpx: Drop connection before TLS finish if h2 requirement
    is not fulfilled
- Fix typo in previous changelog entry
* Tue Sep  1 2015 mpluskal@suse.com
- Update to 1.3.1
  * Limit the number of incoming reserved (remote) streams
  * Add stream public API
  * Rewrite priority tree handling
  * Fix parallel make distcheck
  * Define it and itprep recursive target if
    AM_EXTRA_RECURSIVE_TARGETS is defined
  * fetch-ocsp-response: Handle spurious openssl exist status 0
  * nghttpx: Use nghttp2::ssl::DEFAULT_CIPHER_LIST for backend TLS
    connection
  * nghttpx: Don't allow blacked listed cipher suites for HTTP/2
    connection
  * nghttpx: better handle /dev/stderr and /dev/stdout (Patch from
    Tomasz Buchert)
  * nghttpd: GOAWAY if SSL/TLS requirements for HTTP/2 are not met
  * nghttpd: Return date header field for 304
  * nghttpd: Support HEAD request
  * h2load: Add Timing-script and base URI support (Patch from
    Lucas Pardue)
  * h2load: Add timeout options (Patch from Nora)
- Fix typo in changelog
* Mon Aug 17 2015 mpluskal@suse.com
- Update to 1.2.1
  * doc: Reword the HPACK tutorial (Patch from Tom Harwood)
  * nghttpx: Fix stability issues
  * h2load: Fix crash if -r > -n
* Mon Aug 10 2015 mpluskal@suse.com
- Update to 1.2.0
  * Fix crash if response or data is submitted to closing stream
  * Header table size UINT32_MAX must be accepted
  * Use PROTOCOL_ERROR against DATA sent to idle stream
  * Allow multiple in-flight SETTINGS
  * Strictly check occurrence of dynamic table size update
  * Fix configure warning that 'missing' is missing or too old
  * Fix rm: cannot remove ‘*.rst’: No such file or directory when
    "make clean" (Patch from Alexis La Goutte)
  * doc: Reword some of the server and client tutorial (Patch
    from Tom Harwood)
  * src: Remove monotonic_clock replacement macro for gcc-4.6
  * nghttpx: Add TLS ticket key sharing among nghttpx instances
    using memcached
  * nghttpx: Add shared session cache using memcached
  * nghttpx: Set SSL/TLS session timeout to 12 hours
  * nghttpx: Enable session resumption on HTTP/2 backend
  * nghttpx: Don't rewrite host header field by default
  * nghttpx: Generate new ticket key every 1hr and its life time
    is now 12hrs
  * nghttpx: Don't reuse backend connection if it is not clean
  * nghttpx: Add AES-256-CBC encryption for TLS session ticket
  * nghttpd: Fix the bug that 304 response has non-empty body
  * h2load: Add -r and -C options to h2load (Patch from
    Nora Shoemaker)
- Changes for 1.1.2
  * Fix linker error with libnghttp2_asio
  * Allow custom installation location for Python bindings
- Drop no longer needed missing_nghttp2_timegm.patch
* Thu Jul 16 2015 mpluskal@suse.com
- Update to 1.1.1
  * nghttpx: Fix various stability issues and memory leak bug
- Changes for 1.1.0
  * Fix DATA is not consumed if nghttp2_http_on_data_chunk failed
  * nghttp2_submit_response and nghttp2_submit_headers may return
  * NGHTTP2_ERR_DATA_EXIST
  * msvc build fixes and enchantments (Patch from Gabi Davar)
  * Compile with IRIX gcc-4.7 (Patch from Klaus Ziegler)
  * nghttp: Add --max-concurrent-streams option
  * nghttp: Add comment on HAR on pushed objects (Patch from
    acesso)
  * nghttpx: Add --include option to read additional configuration
    from given file
  * nghttpx: Add backend routing based on request host and path by
    extending -b option
  * nghttpx: Allow log variable to be enclosed by curly braces for
    disambiguation
  * nghttpx: Add log variables related to SSL/TLS connection
  * h2load: Add --ciphers option
- Add patches
  * missing_nghttp2_timegm.patch to fix building of asio library
  * nghttp2-remove-python-build.patch to fix python bindings
    installation when autotools are used
* Tue Jun 30 2015 mpluskal@suse.com
- Update to 1.0.5
  * Add STREAM_DEP_DEBUG macro switch to enable runtime validation
    of depedency tree
  * Fix another bug in priority handling; sibling's item is not
    queued when ancestor's item is detached
  * nghttpx: Fix crash with --http2-bridge and both frontend and
    backend TLS
* Wed Jun 24 2015 mpluskal@suse.com
- Update to 1.0.4
  * Fix assertion failure in stream_update_dep_on_detach_item
    (GH-264)
- Changes for 1.0.3
  * Fix bug that idle self-depending PRIORITY is not handled
    gracefully
  * Optimize dependency based priority code to Firefox style tree
  * enable third-party for asio_lib too (Patch from Mike
    Frysinger)
  * fetch-ocsp-response: Support LibreSSL, and include port in
    ocsp_host
  * src: Support compile with LibreSSL
  * nghttpx: Fix bug that x-forwarded-proto header field does not
    reflect frontend scheme on HTTP/2 backend
  * nghttpx: Validate :path on SPDY frontend
* Tue Jun 16 2015 mpluskal@suse.com
- Update to 1.0.2
  * Fix bug that data are not consumed for connection in race
    condition (GH-253)
  * Define NGHTTP2_EXTERN to __declspec(dllimport) when using
    nghttp2 for Windows build
  * Translate fetch-ocsp-response into Python
  * libevent-client: Fix bug that path is broken if URI does not
    contain path part
  * python: Call on_close callback when connection is lost for
    server session
  * python: Expose client certificate, if available (Patch from
    Fabian Wiesel)
  * python: Catch and log failure to set TCP_NODELAY (Patch from
    Fabian Wiesel)
  * nghttpx: Add --add-request-header option
  * nghttpx: Make WebSocket upgrade work
  * nghttpx: Fix bug that END_STREAM is not set in backend for
    POST with Upgrade
  * nghttpx: Don't send "Expect" header field twice
* Mon May 25 2015 mpluskal@suse.com
- Update to 1.0.1
  * Include stdint.h instead of inttypes.h when compiled with MSVC
    < 2013
  * Fix invalid memory free on out-of-memory handling
  * integration: Use our own copy of golang spdy package
  * android: Don't link zlib bundled with android NDK
  * Dockerfile.android: Update NDK ver, and ubuntu; build and link
    zlib
  * src, examples: Fix up OpenSSL initialization
  * nghttpx: Allow HTTP Upgrade from POST request if response
    header has not been sent to the client
  * nghttpx: Fix bug that PUSH_PROMISE is sent after associated
    response HEADERS
  * nghttpd: Close connection after settings timeout and GOAWAY
    was sent
  * h2load: Fix bug that NPN fails if ALPN is enabled
* Thu May 21 2015 mpluskal@suse.com
- Update to 1.0.0
  * v1.0.0 introduced backward incompatible changes from 0.7
    series. Read https://nghttp2.org/documentation/package_README.html#migration-from-v0-7-15-or-earlier
    to migrate from older version to this latest version.
- Changes for 0.7.15
  * Hopefully, this is the last release for 0.7.x series.
    Development continues in 1.x series.
  * Access violation in buffers (GH-232) (Patch from Etienne Cimon)
  * Retry finding jemalloc lib by je_malloc_stats_print (GH-233)
  * inflatehd: Fix crash if 'wire' value is not string (GH-235)
  * nghttpx: Revert 585af93 to fix crash with TLS (GH-234)
  * nghttpd: Add --echo-upload option to send back request body
* Wed May 13 2015 mpluskal@suse.com
- Update to 0.7.14
  * Fix global-buffer-overflow in HPACK code
  * Fix doc for nghttp2_select_next_protocol
  * Fix bug that promised stream was not reset on decompression
    error
  * Add systemd and upstart configuration file for nghttpx
    (Patch from Zhuoyun Wei)
  * Improve nghttpx logrotate configuration file (Patch from
    Zhuoyun Wei)
  * Update sphinx_rtd_theme
  * h2load: Update h2load to give connect time and ttfb stats
    (Patch from ericcarlschwartz)
  * nghttpd: Add -m, --max-concurrent-streams option
  * nghttpx: Log absolute URI for HTTP/2 or client proxy request
  * nghttpx: Add --header-field-buffer and --max-header-fields
    options
  * nghttp: Fix assertion error if very large value is given to -t
* Fri May  1 2015 mpluskal@suse.com
- Update to 0.7.13
  * Fix bug that promised stream was not reset by returning
    NGHTTP2_ERR_TEMPORAL_CALLBACK_FAILURE from
    nghttp2_on_header_callback. Instead, associated stream was reset.
  * Allow NGHTTP2_ERR_TEMPORAL_CALLBACK_FAILURE from
    nghttp2_on_begin_headers_callback
  * h2load: Effectively disable flow control by setting large
    window size
  * asio: Graceful shutdown and joinable server (Patch from
    Xiaoguang Sun)
* Mon Apr 20 2015 mpluskal@suse.com
- Update to 0.7.12
  * Fix bug that nghttp2_session_set_next_stream_id accepts invalid
    stream_id
  * HPACK: Rewrite static header table handling
  * HPACK: Never index authorization and small cookie header field
  * Don't install libnghttp2_asio headers if they are disabled
  * doc: Specify program directive so that hyperlink to option is
    correctly pointed to the intended location
  * asio: client: Call error_cb on error occurred in do_read and
    do_write (Fixes GH-207)
  * nghttp: Add --no-push option to disable server push
  * nghttp: Show stream ID in statistics output
  * nghttp: Remove --dep-idle option
  * nghttp: Use same priority anchor nodes as Firefox does
  * nghttpx: Don't push resource if link header has non empty
    loadpolicy
  * nghttpx: Add logging for somewhat important events (logs,
    tickets, and ocsp)
  * nghttpx: Set Downstream to stream user data on HTTP Upgrade
    to h2
* Sun Apr 12 2015 mpluskal@suse.com
- Update to 0.7.11
  * nghttpx: Fix waitpid race condition in ocsp response update
  * nghttp: Consider user-provided :authority header field for SNI
    as well as host header field
- Changes for 0.7.10
  * Make sure that nghttp2 license is MIT license
  * Add nghttp2_session_consume_{connection,stream} to consume
    bytes independent
  * Add nghttp2_send_data_callback to send DATA payload without
    copying "static inline" fix for build with VS2013 (Patch from
    Remo E)
  * Update lib/Makefile.msvc (Patch from Remo E)
  * Remove dependency on libws2_32 on Windows build
  * Define NGHTTP2_EXTERN macro to export function for Windows
    build
  * doc: Generate API doc per function
  * python: Add async body generation support
  * python: Fix pseudo-header field ordering bug
  * nghttpx: Redirect stderr to errorlog file
  * nghttpx: Fix bug that data buffered in SSL object are not
    read
  * nghttpx: Remove --tls-ctx-per-worker option
  * nghttpx: Add OCSP stapling feature
* Sat Apr  4 2015 mpluskal@suse.com
- Enable python bindings
- Update to 0.7.9
  * Implements h2-14 protocol (http://tools.ietf.org/html/draft-ietf-httpbis-http2-14)
  * Implements HPACK 09 (http://tools.ietf.org/html/draft-ietf-httpbis-header-compression-09)
  * h2load: Fix crash if -t > -c
  * h2load: Add -d option to upload data to server
  * nghttpx: Forward only "trailers" keyword in te when forwarding HTTP/2 backend
  * nghttpx: Fix PUSH_PROMISE header field corruption [GH-194]
  * nghttpx: Fix te header field is duplicated when forwarding HTTP/2 backend
  * nghttp, nghttpd: Add --hexdump option to hexdump incoming traffic.
  * examples: Place AM_CPPFLAGS first to use in-package header files first [GH-192]
- Changes for 0.7.8
  * Implements h2-14 protocol (http://tools.ietf.org/html/draft-ietf-httpbis-http2-14)
  * Implements HPACK 09 (http://tools.ietf.org/html/draft-ietf-httpbis-header-compression-09)
  * Validate :path header field for http or https URI scheme
  * NULL-terminate header field name and value presented by callback
  * README.rst: Cleaned up the grammar a bit (Patch from Ross Smith II)
  * h2load: fix for segfault by reserving correct worker count (Patch from Stefan Eissing)
* Wed Mar 18 2015 jengelh@inai.de
- Avoid shipping documentation redundantly. Set RPM groups.
* Fri Mar  6 2015 mpluskal@suse.com
- Fix rpm group
* Tue Mar  3 2015 mpluskal@suse.com
- Update to 0.7.5
  * Implements h2-14 protocol
    (http://tools.ietf.org/html/draft-ietf-httpbis-http2-14)
  * Implements HPACK 09
    (http://tools.ietf.org/html/draft-ietf-httpbis-header-compression-09)
  * Validate HTTP semantics by default
  * Add nghttp2_option_set_no_http_messaging() API function
  * Update http-parser
  * nghttp, nghttpd, nghttpx: Use "sensitive" to indicate
    "never indexed" header field
  * nghttp, nghttpd, nghttpx, h2load: Select/announce h2 in
    ALPN/NPN
  * nghttp: Fix unaligned field output in --stat
  * nghttp: Fix -H does not work with -u upgrade request
  * nghttp: Update resource timing terminology according to
    Resource Timing TR
  * nghttpd: Add -a option which takes an address parameter that
    allows nghttpd to bind to a non-default address. Patch
    from Brian Card
  * nghttpx: Use omit minor version in case of HTTP/2 in via
    header and access log
  * nghttpx: Support UNIX domain socket on both frontend and backend
  * nghttpx: Fix crash in http/1 backend when backend returns more
    bytes than CL
  * nghttpx: Cast configuration value to rlim_t to avoid compile
    error on 32bit
  * nghttpx: Fix 1 second delay in HTTP/2 backend connection
  * nghttpx: Fix request re-submission bug in HTTP/2 backend
  * asio-sv2: Fix compile error with OS X
* Sun Feb 15 2015 mpluskal@suse.com
- Initial packaging of 0.7.4
